@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -48,7 +48,7 @@ class ExtendedNotifiers(HasTraits):
         for listener in fail_listeners:
             self._on_trait_change(listener, "fail", dispatch="extended")
 
-        super(ExtendedNotifiers, self).__init__(**traits)
+        super().__init__(**traits)
 
     ok = Float
     fail = Float
